@@ -14,6 +14,7 @@
 #    under the License.
 
 import re
+import ssl
 import threading
 import time
 
@@ -126,6 +127,21 @@ class OpenDaylightWebsocketClient(object):
                     continue
             except websocket.WebSocketTimeoutException:
                 continue
+            except ssl.SSLError as e:
+                message = e.args[0] if e.args else None
+                # TODO(trozet): Workaround due to SSL Timeout not being caught
+                # in websocket-client lib (issue 387).  Remove when fixed in
+                # websocket-client lib.
+                if message and 'timed out' in message:
+                    continue
+
+                LOG.error("SSL websocket unexpected exception, "
+                          "closing and restarting...", exc_info=True)
+                # TODO(rsood): Websocket reconnect can cause race
+                # conditions
+                self._close_ws(ws)
+                ws = None
+                continue
             except websocket.WebSocketConnectionClosedException:
                 # per websocket-client, "If remote host closed the connection
                 # or some network error happened"
@@ -154,6 +170,7 @@ class OpenDaylightWebsocketClient(object):
         self._close_ws(ws)
 
     def _set_websocket_status(self, status):
+        LOG.info("websocket transition to status %s", status)
         try:
             if self.status_cb:
                 self.status_cb(status)
@@ -188,10 +205,10 @@ class OpenDaylightWebsocketClient(object):
                 LOG.debug("response code bad_request (400)"
                           "check path for websocket connection")
                 raise ValueError(_("bad_request (http400),check path."))
-            else:
-                LOG.warning("websocket connection failed",
-                            exc_info=True)
-                return None
+
+            LOG.warning("websocket connection failed",
+                        exc_info=True)
+            return None
         except Exception:
             LOG.error("websocket subscription failed", exc_info=True)
             return None
@@ -218,9 +235,9 @@ class OpenDaylightWebsocketClient(object):
                 LOG.debug("response code not_found (404)"
                           "unable to websocket connection url")
                 raise ValueError(_("bad_request (http400),check path"))
-            else:
-                LOG.warning("websocket connection failed")
-                return None
+
+            LOG.warning("websocket connection failed")
+            return None
         except ValueError:
             with excutils.save_and_reraise_exception():
                 LOG.error("websocket subscribe got invalid stream name")
@@ -239,10 +256,10 @@ class OpenDaylightWebsocketClient(object):
         except ValueError:
             with excutils.save_and_reraise_exception():
                 LOG.error("websocket create connection invalid URL")
-        except websocket.WebSocketBadStatusException:
-            LOG.error("webSocket bad status exception", exc_info=True)
-            return None
         except Exception:
+            # Although a number of exceptions can occur here
+            # we handle them all the same way, return None.
+            # As such, enough to just "except Exception."
             LOG.exception("websocket create connection failed",
                           exc_info=True)
             return None
@@ -258,6 +275,10 @@ class OpenDaylightWebsocketClient(object):
         stream_url = self._subscribe_websocket()
         if stream_url is None:
             return None
+        if 'https:' in self.odl_rest_client.url and 'wss:' not in stream_url:
+            LOG.warning('TLS ODL URL detected, but websocket URL is not.  '
+                        'Forcing websocket URL to TLS')
+            stream_url = stream_url.replace('ws:', 'wss:')
         # Delay here causes websocket notification lose (ODL Bug 8299)
         ws = self._socket_create_connection(stream_url)
         if ws is not None:
